/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */
package org.greenstone.gatherer.gui;

/**************************************************************************************
 * Title:        Gatherer
 * Description:  The Gatherer: a tool for gathering and enriching a digital collection.
 * Company:      The University of Waikato
 * Written:        /  /02
 * Revised:      03/10/02 - Commented
 **************************************************************************************/
import java.awt.Color;
import java.io.Serializable;
/** The coloring object is part of the Gatherers configuration, and stores the various colours used to render parts of the interface. In general these colours fall into three groups, those for the workspace, those for the collection and all other colour components.
 * @author John Thompson
 * @version 2.3
 */
public class Coloring 
    implements Serializable {
    /** The color of a buttons background. */
    public Color button_background;
    /** The color of a buttons foreground. */
    public Color button_foreground;
    /** The background color used to indicate that a button has been clicked or selected. */
    public Color button_selected_background;
    /** The foreground color used to indicate that a button has been clicked or selected. */
    public Color button_selected_foreground;
    /** The color used for the background of the collection label. */
    public Color collection_heading_background   = null;
    /** The color used for the text of the collection label. */
    public Color collection_heading_foreground   = null;
    /** The color used for the background of controls in the collection that are non-editable. */
    public Color collection_noneditable_background = null;
    /** The color used for the foreground of controls in the collection that are non-editable. */
    public Color collection_noneditable_foreground = null;
    /** The color used for the background of a selection from the collection. */
    public Color collection_selection_background = null;
    /** The color used for the text of a selection from the collection. */
    public Color collection_selection_foreground = null;
    /** The color used for the background of a collection oriented component. */
    public Color collection_tree_background      = null;
    /** The color used for the text of a collection oriented component. */
    public Color collection_tree_foreground      = null;	 
    /** The color used for the background of an error state oriented component. */
    public Color error_background;
    /** The color used for the text of an error state oriented component. */
    public Color error_foreground;
    /** The color used for the background (behind the slider) part of a scroll bar. */
    public Color scrollbar_background;
    /** The color usef for the foreground (slider and arrows) parts of a scroll bar. */
    public Color scrollbar_foreground;
    /** The color used for the background of the workspace label. */
    public Color workspace_heading_background    = null;
    /** The color used for the text of the workspace label. */
    public Color workspace_heading_foreground    = null;
    /** The color used for the background of a selection from the workspace. */
    public Color workspace_selection_background  = null;
    /** The color used for the text of a selection from the workspace. */
    public Color workspace_selection_foreground  = null;
    /** The color used for the background of a workspace oriented component. */
    public Color workspace_tree_background       = null;
    /** The color used for the text of a workspace oriented component. */
    public Color workspace_tree_foreground       = null;
    /** Constructor. Uses default colors. 
     */
    public Coloring() {
	// Default Values.
	// Collection
	collection_heading_background = new Color(176, 208, 176);  
	collection_heading_foreground = Color.black;
	collection_selection_background = new Color(128, 180, 216);
	collection_selection_foreground = Color.black;
	collection_tree_background = new Color(224, 240, 224);
	collection_tree_foreground = Color.black;	 
	collection_noneditable_background = Color.lightGray;
	collection_noneditable_foreground = Color.black;
	// Other
	button_background = Color.white;
	button_foreground = Color.black;
	button_selected_background = new Color(128, 180, 216);
	button_selected_foreground = Color.white;
	error_background = new Color(250, 180, 180);
	error_foreground = Color.red;
	scrollbar_background = Color.lightGray;
	scrollbar_foreground = Color.white;
	// Workspace
	workspace_heading_background = new Color(128, 180, 216);
	workspace_heading_foreground = Color.black;
	workspace_selection_background = new Color(176, 208, 176);
	workspace_selection_foreground = Color.black;
	workspace_tree_background = new Color(218, 237, 252);
	workspace_tree_foreground = Color.black;
    }
}
